"""
Core implementations for the Imaging Server Kit.
"""

from .decorator import algorithm_server, parse_params
from .encoding import encode_contents, decode_contents
from .errors import (
    AlgorithmNotFoundError,
    AlgorithmServerError,
    InvalidAlgorithmParametersError,
    ServerRequestError,
    AlgorithmTimeoutError,
)
from .geometry import (
    mask2features,
    instance_mask2features,
    features2mask,
    features2instance_mask,
    features2mask_3d,
    mask2features_3d,
    instance_mask2features_3d,
    features2instance_mask_3d,
    boxes2features,
    features2boxes,
    points2features,
    features2points,
    vectors2features,
    features2vectors,
)
from .serialization import serialize_result_tuple, deserialize_result_tuple
from .server import (
    AlgorithmServer,
    Parameters,
    load_from_yaml,
    parse_algo_params_schema,
    ALGORITHM_HUB_URL,
    PROCESS_TIMEOUT_SEC,
)
from .ui_library import (
    ParameterUI,
    DropDownUI,
    FloatSpinBoxUI,
    IntSpinBoxUI,
    BoolUI,
    StringUI,
    ImageUI,
    MaskUI,
    PointsUI,
    VectorsUI,
    ShapesUI,
    TracksUI,
)

__all__ = [
    "algorithm_server",
    "encode_contents",
    "decode_contents",
    "AlgorithmNotFoundError",
    "AlgorithmServerError",
    "InvalidAlgorithmParametersError",
    "ServerRequestError",
    "AlgorithmTimeoutError",
    "mask2features",
    "instance_mask2features",
    "features2mask",
    "features2instance_mask",
    "features2mask_3d",
    "mask2features_3d",
    "instance_mask2features_3d",
    "features2instance_mask_3d",
    "boxes2features",
    "features2boxes",
    "points2features",
    "features2points",
    "vectors2features",
    "features2vectors",
    "serialize_result_tuple",
    "deserialize_result_tuple",
    "AlgorithmServer",
    "Parameters",
    "load_from_yaml",
    "parse_algo_params_schema",
    "ALGORITHM_HUB_URL",
    "PROCESS_TIMEOUT_SEC",
    "ParameterUI",
    "DropDownUI",
    "FloatSpinBoxUI",
    "IntSpinBoxUI",
    "BoolUI",
    "StringUI",
    "ImageUI",
    "MaskUI",
    "PointsUI",
    "VectorsUI",
    "ShapesUI",
    "TracksUI",
]
